from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Birthday(BaseModel):
    """
    types.Birthday
    ID: 0x6c8e1e06
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Birthday', 'Birthday'] = pydantic.Field(
        'types.Birthday',
        alias='_'
    )

    day: int
    month: int
    year: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PhoneCallDiscardReason - Layer 181
PhoneCallDiscardReason = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PhoneCallDiscardReasonBusy,
            pydantic.Tag('PhoneCallDiscardReasonBusy')
        ],
        typing.Annotated[
            types.PhoneCallDiscardReasonDisconnect,
            pydantic.Tag('PhoneCallDiscardReasonDisconnect')
        ],
        typing.Annotated[
            types.PhoneCallDiscardReasonHangup,
            pydantic.Tag('PhoneCallDiscardReasonHangup')
        ],
        typing.Annotated[
            types.PhoneCallDiscardReasonMissed,
            pydantic.Tag('PhoneCallDiscardReasonMissed')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class FinishJob(BaseModel):
    """
    functions.smsjobs.FinishJob
    ID: 0x4f1ebf24
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.smsjobs.FinishJob', 'FinishJob'] = pydantic.Field(
        'functions.smsjobs.FinishJob',
        alias='_'
    )

    job_id: str
    error: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebPage(BaseModel):
    """
    types.messages.WebPage
    ID: 0xfd5e12bd
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.WebPage', 'WebPage'] = pydantic.Field(
        'types.messages.WebPage',
        alias='_'
    )

    webpage: "base.WebPage"
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputStickerSet - Layer 181
InputStickerSet = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputStickerSetAnimatedEmoji,
            pydantic.Tag('InputStickerSetAnimatedEmoji')
        ],
        typing.Annotated[
            types.InputStickerSetAnimatedEmojiAnimations,
            pydantic.Tag('InputStickerSetAnimatedEmojiAnimations')
        ],
        typing.Annotated[
            types.InputStickerSetDice,
            pydantic.Tag('InputStickerSetDice')
        ],
        typing.Annotated[
            types.InputStickerSetEmojiChannelDefaultStatuses,
            pydantic.Tag('InputStickerSetEmojiChannelDefaultStatuses')
        ],
        typing.Annotated[
            types.InputStickerSetEmojiDefaultStatuses,
            pydantic.Tag('InputStickerSetEmojiDefaultStatuses')
        ],
        typing.Annotated[
            types.InputStickerSetEmojiDefaultTopicIcons,
            pydantic.Tag('InputStickerSetEmojiDefaultTopicIcons')
        ],
        typing.Annotated[
            types.InputStickerSetEmojiGenericAnimations,
            pydantic.Tag('InputStickerSetEmojiGenericAnimations')
        ],
        typing.Annotated[
            types.InputStickerSetEmpty,
            pydantic.Tag('InputStickerSetEmpty')
        ],
        typing.Annotated[
            types.InputStickerSetID,
            pydantic.Tag('InputStickerSetID')
        ],
        typing.Annotated[
            types.InputStickerSetPremiumGifts,
            pydantic.Tag('InputStickerSetPremiumGifts')
        ],
        typing.Annotated[
            types.InputStickerSetShortName,
            pydantic.Tag('InputStickerSetShortName')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetBotCallbackAnswer(BaseModel):
    """
    functions.messages.GetBotCallbackAnswer
    ID: 0x9342ca07
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetBotCallbackAnswer', 'GetBotCallbackAnswer'] = pydantic.Field(
        'functions.messages.GetBotCallbackAnswer',
        alias='_'
    )

    peer: "base.InputPeer"
    msg_id: int
    game: typing.Optional[bool] = None
    data: typing.Optional[Bytes] = None
    password: typing.Optional["base.InputCheckPasswordSRP"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Blocked(BaseModel):
    """
    types.contacts.Blocked
    ID: 0xade1591
    Layer: 181
    """
    QUALNAME: typing.Literal['types.contacts.Blocked', 'Blocked'] = pydantic.Field(
        'types.contacts.Blocked',
        alias='_'
    )

    blocked: list["base.PeerBlocked"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Chat - Layer 181
Chat = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.Channel,
            pydantic.Tag('Channel')
        ],
        typing.Annotated[
            types.ChannelForbidden,
            pydantic.Tag('ChannelForbidden')
        ],
        typing.Annotated[
            types.Chat,
            pydantic.Tag('Chat')
        ],
        typing.Annotated[
            types.ChatEmpty,
            pydantic.Tag('ChatEmpty')
        ],
        typing.Annotated[
            types.ChatForbidden,
            pydantic.Tag('ChatForbidden')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.Themes - Layer 181
Themes = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.account.Themes,
            pydantic.Tag('account.Themes'),
            pydantic.Tag('Themes')
        ],
        typing.Annotated[
            types.account.ThemesNotModified,
            pydantic.Tag('account.ThemesNotModified'),
            pydantic.Tag('ThemesNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EditGroupCallParticipant(BaseModel):
    """
    functions.phone.EditGroupCallParticipant
    ID: 0xa5273abf
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.EditGroupCallParticipant', 'EditGroupCallParticipant'] = pydantic.Field(
        'functions.phone.EditGroupCallParticipant',
        alias='_'
    )

    call: "base.InputGroupCall"
    participant: "base.InputPeer"
    muted: typing.Optional[bool] = None
    volume: typing.Optional[int] = None
    raise_hand: typing.Optional[bool] = None
    video_stopped: typing.Optional[bool] = None
    video_paused: typing.Optional[bool] = None
    presentation_paused: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PrivacyKey - Layer 181
PrivacyKey = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PrivacyKeyAbout,
            pydantic.Tag('PrivacyKeyAbout')
        ],
        typing.Annotated[
            types.PrivacyKeyAddedByPhone,
            pydantic.Tag('PrivacyKeyAddedByPhone')
        ],
        typing.Annotated[
            types.PrivacyKeyBirthday,
            pydantic.Tag('PrivacyKeyBirthday')
        ],
        typing.Annotated[
            types.PrivacyKeyChatInvite,
            pydantic.Tag('PrivacyKeyChatInvite')
        ],
        typing.Annotated[
            types.PrivacyKeyForwards,
            pydantic.Tag('PrivacyKeyForwards')
        ],
        typing.Annotated[
            types.PrivacyKeyPhoneCall,
            pydantic.Tag('PrivacyKeyPhoneCall')
        ],
        typing.Annotated[
            types.PrivacyKeyPhoneNumber,
            pydantic.Tag('PrivacyKeyPhoneNumber')
        ],
        typing.Annotated[
            types.PrivacyKeyPhoneP2P,
            pydantic.Tag('PrivacyKeyPhoneP2P')
        ],
        typing.Annotated[
            types.PrivacyKeyProfilePhoto,
            pydantic.Tag('PrivacyKeyProfilePhoto')
        ],
        typing.Annotated[
            types.PrivacyKeyStatusTimestamp,
            pydantic.Tag('PrivacyKeyStatusTimestamp')
        ],
        typing.Annotated[
            types.PrivacyKeyVoiceMessages,
            pydantic.Tag('PrivacyKeyVoiceMessages')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BotCommandScope - Layer 181
BotCommandScope = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.BotCommandScopeChatAdmins,
            pydantic.Tag('BotCommandScopeChatAdmins')
        ],
        typing.Annotated[
            types.BotCommandScopeChats,
            pydantic.Tag('BotCommandScopeChats')
        ],
        typing.Annotated[
            types.BotCommandScopeDefault,
            pydantic.Tag('BotCommandScopeDefault')
        ],
        typing.Annotated[
            types.BotCommandScopePeer,
            pydantic.Tag('BotCommandScopePeer')
        ],
        typing.Annotated[
            types.BotCommandScopePeerAdmins,
            pydantic.Tag('BotCommandScopePeerAdmins')
        ],
        typing.Annotated[
            types.BotCommandScopePeerUser,
            pydantic.Tag('BotCommandScopePeerUser')
        ],
        typing.Annotated[
            types.BotCommandScopeUsers,
            pydantic.Tag('BotCommandScopeUsers')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetCollectibleInfo(BaseModel):
    """
    functions.fragment.GetCollectibleInfo
    ID: 0xbe1e85ba
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.fragment.GetCollectibleInfo', 'GetCollectibleInfo'] = pydantic.Field(
        'functions.fragment.GetCollectibleInfo',
        alias='_'
    )

    collectible: "base.InputCollectible"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DcOption(BaseModel):
    """
    types.DcOption
    ID: 0x18b7a10d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DcOption', 'DcOption'] = pydantic.Field(
        'types.DcOption',
        alias='_'
    )

    id: int
    ip_address: str
    port: int
    ipv6: typing.Optional[bool] = None
    media_only: typing.Optional[bool] = None
    tcpo_only: typing.Optional[bool] = None
    cdn: typing.Optional[bool] = None
    static: typing.Optional[bool] = None
    this_port_only: typing.Optional[bool] = None
    secret: typing.Optional[Bytes] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PeerColorProfileSet(BaseModel):
    """
    types.help.PeerColorProfileSet
    ID: 0x767d61eb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.PeerColorProfileSet', 'PeerColorProfileSet'] = pydantic.Field(
        'types.help.PeerColorProfileSet',
        alias='_'
    )

    palette_colors: list[int]
    bg_colors: list[int]
    story_colors: list[int]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendStory(BaseModel):
    """
    functions.stories.SendStory
    ID: 0xe4e6694b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stories.SendStory', 'SendStory'] = pydantic.Field(
        'functions.stories.SendStory',
        alias='_'
    )

    peer: "base.InputPeer"
    media: "base.InputMedia"
    privacy_rules: list["base.InputPrivacyRule"]
    random_id: int
    pinned: typing.Optional[bool] = None
    noforwards: typing.Optional[bool] = None
    fwd_modified: typing.Optional[bool] = None
    media_areas: typing.Optional[list["base.MediaArea"]] = None
    caption: typing.Optional[str] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None
    period: typing.Optional[int] = None
    fwd_from_id: typing.Optional["base.InputPeer"] = None
    fwd_from_story: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetLocated(BaseModel):
    """
    functions.contacts.GetLocated
    ID: 0xd348bc44
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.contacts.GetLocated', 'GetLocated'] = pydantic.Field(
        'functions.contacts.GetLocated',
        alias='_'
    )

    geo_point: "base.InputGeoPoint"
    background: typing.Optional[bool] = None
    self_expires: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# upload.WebFile - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
WebFile = typing.Union[
    typing.Annotated[
        types.upload.WebFile,
        pydantic.Tag('upload.WebFile'),
        pydantic.Tag('WebFile')
    ]
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# DocumentAttribute - Layer 181
DocumentAttribute = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.DocumentAttributeAnimated,
            pydantic.Tag('DocumentAttributeAnimated')
        ],
        typing.Annotated[
            types.DocumentAttributeAudio,
            pydantic.Tag('DocumentAttributeAudio')
        ],
        typing.Annotated[
            types.DocumentAttributeCustomEmoji,
            pydantic.Tag('DocumentAttributeCustomEmoji')
        ],
        typing.Annotated[
            types.DocumentAttributeFilename,
            pydantic.Tag('DocumentAttributeFilename')
        ],
        typing.Annotated[
            types.DocumentAttributeHasStickers,
            pydantic.Tag('DocumentAttributeHasStickers')
        ],
        typing.Annotated[
            types.DocumentAttributeImageSize,
            pydantic.Tag('DocumentAttributeImageSize')
        ],
        typing.Annotated[
            types.DocumentAttributeSticker,
            pydantic.Tag('DocumentAttributeSticker')
        ],
        typing.Annotated[
            types.DocumentAttributeVideo,
            pydantic.Tag('DocumentAttributeVideo')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class KeyboardButtonRequestPeer(BaseModel):
    """
    types.KeyboardButtonRequestPeer
    ID: 0x53d7bfd8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.KeyboardButtonRequestPeer', 'KeyboardButtonRequestPeer'] = pydantic.Field(
        'types.KeyboardButtonRequestPeer',
        alias='_'
    )

    text: str
    button_id: int
    peer_type: "base.RequestPeerType"
    max_quantity: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PasswordInputSettings(BaseModel):
    """
    types.account.PasswordInputSettings
    ID: 0xc23727c9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.PasswordInputSettings', 'PasswordInputSettings'] = pydantic.Field(
        'types.account.PasswordInputSettings',
        alias='_'
    )

    new_algo: typing.Optional["base.PasswordKdfAlgo"] = None
    new_password_hash: typing.Optional[Bytes] = None
    hint: typing.Optional[str] = None
    email: typing.Optional[str] = None
    new_secure_settings: typing.Optional["base.SecureSecretSettings"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotInfo(BaseModel):
    """
    types.BotInfo
    ID: 0x8f300b57
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BotInfo', 'BotInfo'] = pydantic.Field(
        'types.BotInfo',
        alias='_'
    )

    user_id: typing.Optional[int] = None
    description: typing.Optional[str] = None
    description_photo: typing.Optional["base.Photo"] = None
    description_document: typing.Optional["base.Document"] = None
    commands: typing.Optional[list["base.BotCommand"]] = None
    menu_button: typing.Optional["base.BotMenuButton"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EditInlineBotMessage(BaseModel):
    """
    functions.messages.EditInlineBotMessage
    ID: 0x83557dba
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.EditInlineBotMessage', 'EditInlineBotMessage'] = pydantic.Field(
        'functions.messages.EditInlineBotMessage',
        alias='_'
    )

    id: "base.InputBotInlineMessageID"
    no_webpage: typing.Optional[bool] = None
    invert_media: typing.Optional[bool] = None
    message: typing.Optional[str] = None
    media: typing.Optional["base.InputMedia"] = None
    reply_markup: typing.Optional["base.ReplyMarkup"] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# contacts.Blocked - Layer 181
Blocked = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.contacts.Blocked,
            pydantic.Tag('contacts.Blocked'),
            pydantic.Tag('Blocked')
        ],
        typing.Annotated[
            types.contacts.BlockedSlice,
            pydantic.Tag('contacts.BlockedSlice'),
            pydantic.Tag('BlockedSlice')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Page(BaseModel):
    """
    types.Page
    ID: 0x98657f0d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Page', 'Page'] = pydantic.Field(
        'types.Page',
        alias='_'
    )

    url: str
    blocks: list["base.PageBlock"]
    photos: list["base.Photo"]
    documents: list["base.Document"]
    part: typing.Optional[bool] = None
    rtl: typing.Optional[bool] = None
    v2: typing.Optional[bool] = None
    views: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AllowSendMessage(BaseModel):
    """
    functions.bots.AllowSendMessage
    ID: 0xf132e3ef
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.bots.AllowSendMessage', 'AllowSendMessage'] = pydantic.Field(
        'functions.bots.AllowSendMessage',
        alias='_'
    )

    bot: "base.InputUser"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaPoll(BaseModel):
    """
    types.InputMediaPoll
    ID: 0xf94e5f1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaPoll', 'InputMediaPoll'] = pydantic.Field(
        'types.InputMediaPoll',
        alias='_'
    )

    poll: "base.Poll"
    correct_answers: typing.Optional[list[Bytes]] = None
    solution: typing.Optional[str] = None
    solution_entities: typing.Optional[list["base.MessageEntity"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.FavedStickers - Layer 181
FavedStickers = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.FavedStickers,
            pydantic.Tag('messages.FavedStickers'),
            pydantic.Tag('FavedStickers')
        ],
        typing.Annotated[
            types.messages.FavedStickersNotModified,
            pydantic.Tag('messages.FavedStickersNotModified'),
            pydantic.Tag('FavedStickersNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.SavedRingtones - Layer 181
SavedRingtones = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.account.SavedRingtones,
            pydantic.Tag('account.SavedRingtones'),
            pydantic.Tag('SavedRingtones')
        ],
        typing.Annotated[
            types.account.SavedRingtonesNotModified,
            pydantic.Tag('account.SavedRingtonesNotModified'),
            pydantic.Tag('SavedRingtonesNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateChannelPinnedTopic(BaseModel):
    """
    types.UpdateChannelPinnedTopic
    ID: 0x192efbe3
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateChannelPinnedTopic', 'UpdateChannelPinnedTopic'] = pydantic.Field(
        'types.UpdateChannelPinnedTopic',
        alias='_'
    )

    channel_id: int
    topic_id: int
    pinned: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Message - Layer 181
Message = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.Message,
            pydantic.Tag('Message')
        ],
        typing.Annotated[
            types.MessageEmpty,
            pydantic.Tag('MessageEmpty')
        ],
        typing.Annotated[
            types.MessageService,
            pydantic.Tag('MessageService')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UrlAuthResultRequest(BaseModel):
    """
    types.UrlAuthResultRequest
    ID: 0x92d33a0e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UrlAuthResultRequest', 'UrlAuthResultRequest'] = pydantic.Field(
        'types.UrlAuthResultRequest',
        alias='_'
    )

    bot: "base.User"
    domain: str
    request_write_access: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateTheme(BaseModel):
    """
    functions.account.UpdateTheme
    ID: 0x2bf40ccc
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UpdateTheme', 'UpdateTheme'] = pydantic.Field(
        'functions.account.UpdateTheme',
        alias='_'
    )

    format: str
    theme: "base.InputTheme"
    slug: typing.Optional[str] = None
    title: typing.Optional[str] = None
    document: typing.Optional["base.InputDocument"] = None
    settings: typing.Optional[list["base.InputThemeSettings"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPaymentCredentials - Layer 181
InputPaymentCredentials = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputPaymentCredentials,
            pydantic.Tag('InputPaymentCredentials')
        ],
        typing.Annotated[
            types.InputPaymentCredentialsApplePay,
            pydantic.Tag('InputPaymentCredentialsApplePay')
        ],
        typing.Annotated[
            types.InputPaymentCredentialsGooglePay,
            pydantic.Tag('InputPaymentCredentialsGooglePay')
        ],
        typing.Annotated[
            types.InputPaymentCredentialsSaved,
            pydantic.Tag('InputPaymentCredentialsSaved')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotDeleteBusinessMessage(BaseModel):
    """
    types.UpdateBotDeleteBusinessMessage
    ID: 0xa02a982e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotDeleteBusinessMessage', 'UpdateBotDeleteBusinessMessage'] = pydantic.Field(
        'types.UpdateBotDeleteBusinessMessage',
        alias='_'
    )

    connection_id: str
    peer: "base.Peer"
    messages: list[int]
    qts: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetDiscussionGroup(BaseModel):
    """
    functions.channels.SetDiscussionGroup
    ID: 0x40582bb2
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.SetDiscussionGroup', 'SetDiscussionGroup'] = pydantic.Field(
        'functions.channels.SetDiscussionGroup',
        alias='_'
    )

    broadcast: "base.InputChannel"
    group: "base.InputChannel"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BotInlineMessage - Layer 181
BotInlineMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.BotInlineMessageMediaAuto,
            pydantic.Tag('BotInlineMessageMediaAuto')
        ],
        typing.Annotated[
            types.BotInlineMessageMediaContact,
            pydantic.Tag('BotInlineMessageMediaContact')
        ],
        typing.Annotated[
            types.BotInlineMessageMediaGeo,
            pydantic.Tag('BotInlineMessageMediaGeo')
        ],
        typing.Annotated[
            types.BotInlineMessageMediaInvoice,
            pydantic.Tag('BotInlineMessageMediaInvoice')
        ],
        typing.Annotated[
            types.BotInlineMessageMediaVenue,
            pydantic.Tag('BotInlineMessageMediaVenue')
        ],
        typing.Annotated[
            types.BotInlineMessageMediaWebPage,
            pydantic.Tag('BotInlineMessageMediaWebPage')
        ],
        typing.Annotated[
            types.BotInlineMessageText,
            pydantic.Tag('BotInlineMessageText')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# stats.MegagroupStats - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
MegagroupStats = typing.Union[
    typing.Annotated[
        types.stats.MegagroupStats,
        pydantic.Tag('stats.MegagroupStats'),
        pydantic.Tag('MegagroupStats')
    ]
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBotInlineMessageMediaAuto(BaseModel):
    """
    types.InputBotInlineMessageMediaAuto
    ID: 0x3380c786
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBotInlineMessageMediaAuto', 'InputBotInlineMessageMediaAuto'] = pydantic.Field(
        'types.InputBotInlineMessageMediaAuto',
        alias='_'
    )

    message: str
    invert_media: typing.Optional[bool] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None
    reply_markup: typing.Optional["base.ReplyMarkup"] = None



import base64
import typing
from datetime import datetime

import pydantic


def _serialize_bytes(v: bytes) -> str:
    return base64.b64encode(v).decode('ascii')


def _validate_bytes(v: bytes) -> bytes:
    if isinstance(v, bytes):
        return v

    if isinstance(v, str):
        try:
            return base64.b64decode(v.encode('ascii'))
        except Exception as e:
            raise ValueError(f"Invalid base64-encoded bytes: {e}")

    return v


Bytes = typing.Annotated[
    bytes,
    pydantic.PlainSerializer(_serialize_bytes, return_type=str, when_used="json-unless-none"),
    pydantic.BeforeValidator(_validate_bytes),
]


def _serialize_datetime(v: datetime) -> int:
    return int(v.timestamp())


def _validate_datetime(v: datetime) -> datetime:
    if isinstance(v, datetime):
        return v

    if isinstance(v, (int, float)):
        return datetime.fromtimestamp(v)

    if isinstance(v, str):
        try:
            return datetime.fromisoformat(v)
        except Exception:
            pass

        try:
            return datetime.fromtimestamp(int(v))
        except Exception:
            pass

    raise ValueError(f"Invalid datetime value: {v}")


Datetime = typing.Annotated[
    datetime,
    pydantic.PlainSerializer(_serialize_datetime, return_type=int, when_used="json-unless-none"),
    pydantic.BeforeValidator(_validate_datetime),
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputMedia - Layer 181
InputMedia = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputMediaContact,
            pydantic.Tag('InputMediaContact')
        ],
        typing.Annotated[
            types.InputMediaDice,
            pydantic.Tag('InputMediaDice')
        ],
        typing.Annotated[
            types.InputMediaDocument,
            pydantic.Tag('InputMediaDocument')
        ],
        typing.Annotated[
            types.InputMediaDocumentExternal,
            pydantic.Tag('InputMediaDocumentExternal')
        ],
        typing.Annotated[
            types.InputMediaEmpty,
            pydantic.Tag('InputMediaEmpty')
        ],
        typing.Annotated[
            types.InputMediaGame,
            pydantic.Tag('InputMediaGame')
        ],
        typing.Annotated[
            types.InputMediaGeoLive,
            pydantic.Tag('InputMediaGeoLive')
        ],
        typing.Annotated[
            types.InputMediaGeoPoint,
            pydantic.Tag('InputMediaGeoPoint')
        ],
        typing.Annotated[
            types.InputMediaInvoice,
            pydantic.Tag('InputMediaInvoice')
        ],
        typing.Annotated[
            types.InputMediaPhoto,
            pydantic.Tag('InputMediaPhoto')
        ],
        typing.Annotated[
            types.InputMediaPhotoExternal,
            pydantic.Tag('InputMediaPhotoExternal')
        ],
        typing.Annotated[
            types.InputMediaPoll,
            pydantic.Tag('InputMediaPoll')
        ],
        typing.Annotated[
            types.InputMediaStory,
            pydantic.Tag('InputMediaStory')
        ],
        typing.Annotated[
            types.InputMediaUploadedDocument,
            pydantic.Tag('InputMediaUploadedDocument')
        ],
        typing.Annotated[
            types.InputMediaUploadedPhoto,
            pydantic.Tag('InputMediaUploadedPhoto')
        ],
        typing.Annotated[
            types.InputMediaVenue,
            pydantic.Tag('InputMediaVenue')
        ],
        typing.Annotated[
            types.InputMediaWebPage,
            pydantic.Tag('InputMediaWebPage')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputEncryptedFile - Layer 181
InputEncryptedFile = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputEncryptedFile,
            pydantic.Tag('InputEncryptedFile')
        ],
        typing.Annotated[
            types.InputEncryptedFileBigUploaded,
            pydantic.Tag('InputEncryptedFileBigUploaded')
        ],
        typing.Annotated[
            types.InputEncryptedFileEmpty,
            pydantic.Tag('InputEncryptedFileEmpty')
        ],
        typing.Annotated[
            types.InputEncryptedFileUploaded,
            pydantic.Tag('InputEncryptedFileUploaded')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from .save_file_part import SaveFilePart
from .get_file import GetFile
from .save_big_file_part import SaveBigFilePart
from .get_web_file import GetWebFile
from .get_cdn_file import GetCdnFile
from .reupload_cdn_file import ReuploadCdnFile
from .get_cdn_file_hashes import GetCdnFileHashes
from .get_file_hashes import GetFileHashes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockEmbedPost(BaseModel):
    """
    types.PageBlockEmbedPost
    ID: 0xf259a80b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockEmbedPost', 'PageBlockEmbedPost'] = pydantic.Field(
        'types.PageBlockEmbedPost',
        alias='_'
    )

    url: str
    webpage_id: int
    author_photo_id: int
    author: str
    date: Datetime
    blocks: list["base.PageBlock"]
    caption: "base.PageCaption"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageEntityMentionName(BaseModel):
    """
    types.MessageEntityMentionName
    ID: 0xdc7b1140
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageEntityMentionName', 'MessageEntityMentionName'] = pydantic.Field(
        'types.MessageEntityMentionName',
        alias='_'
    )

    offset: int
    length: int
    user_id: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EmojiGroup - Layer 181
EmojiGroup = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.EmojiGroup,
            pydantic.Tag('EmojiGroup')
        ],
        typing.Annotated[
            types.EmojiGroupGreeting,
            pydantic.Tag('EmojiGroupGreeting')
        ],
        typing.Annotated[
            types.EmojiGroupPremium,
            pydantic.Tag('EmojiGroupPremium')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatInviteImporter(BaseModel):
    """
    types.ChatInviteImporter
    ID: 0x8c5adfd9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatInviteImporter', 'ChatInviteImporter'] = pydantic.Field(
        'types.ChatInviteImporter',
        alias='_'
    )

    user_id: int
    date: Datetime
    requested: typing.Optional[bool] = None
    via_chatlist: typing.Optional[bool] = None
    about: typing.Optional[str] = None
    approved_by: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetLeftChannels(BaseModel):
    """
    functions.channels.GetLeftChannels
    ID: 0x8341ecc0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.GetLeftChannels', 'GetLeftChannels'] = pydantic.Field(
        'functions.channels.GetLeftChannels',
        alias='_'
    )

    offset: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PaymentRequestedInfo(BaseModel):
    """
    types.PaymentRequestedInfo
    ID: 0x909c3f94
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PaymentRequestedInfo', 'PaymentRequestedInfo'] = pydantic.Field(
        'types.PaymentRequestedInfo',
        alias='_'
    )

    name: typing.Optional[str] = None
    phone: typing.Optional[str] = None
    email: typing.Optional[str] = None
    shipping_address: typing.Optional["base.PostAddress"] = None



from .contacts_not_modified import ContactsNotModified
from .contacts import Contacts
from .imported_contacts import ImportedContacts
from .blocked import Blocked
from .blocked_slice import BlockedSlice
from .found import Found
from .resolved_peer import ResolvedPeer
from .top_peers_not_modified import TopPeersNotModified
from .top_peers import TopPeers
from .top_peers_disabled import TopPeersDisabled
from .contact_birthdays import ContactBirthdays



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BusinessGreetingMessage(BaseModel):
    """
    types.BusinessGreetingMessage
    ID: 0xe519abab
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BusinessGreetingMessage', 'BusinessGreetingMessage'] = pydantic.Field(
        'types.BusinessGreetingMessage',
        alias='_'
    )

    shortcut_id: int
    recipients: "base.BusinessRecipients"
    no_activity_days: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BaseTheme - Layer 181
BaseTheme = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.BaseThemeArctic,
            pydantic.Tag('BaseThemeArctic')
        ],
        typing.Annotated[
            types.BaseThemeClassic,
            pydantic.Tag('BaseThemeClassic')
        ],
        typing.Annotated[
            types.BaseThemeDay,
            pydantic.Tag('BaseThemeDay')
        ],
        typing.Annotated[
            types.BaseThemeNight,
            pydantic.Tag('BaseThemeNight')
        ],
        typing.Annotated[
            types.BaseThemeTinted,
            pydantic.Tag('BaseThemeTinted')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CancelCode(BaseModel):
    """
    functions.auth.CancelCode
    ID: 0x1f040578
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.CancelCode', 'CancelCode'] = pydantic.Field(
        'functions.auth.CancelCode',
        alias='_'
    )

    phone_number: str
    phone_code_hash: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputWebFileAudioAlbumThumbLocation(BaseModel):
    """
    types.InputWebFileAudioAlbumThumbLocation
    ID: 0xf46fe924
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputWebFileAudioAlbumThumbLocation', 'InputWebFileAudioAlbumThumbLocation'] = pydantic.Field(
        'types.InputWebFileAudioAlbumThumbLocation',
        alias='_'
    )

    small: typing.Optional[bool] = None
    document: typing.Optional["base.InputDocument"] = None
    title: typing.Optional[str] = None
    performer: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputCollectible - Layer 181
InputCollectible = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputCollectiblePhone,
            pydantic.Tag('InputCollectiblePhone')
        ],
        typing.Annotated[
            types.InputCollectibleUsername,
            pydantic.Tag('InputCollectibleUsername')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.WallPapers - Layer 181
WallPapers = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.account.WallPapers,
            pydantic.Tag('account.WallPapers'),
            pydantic.Tag('WallPapers')
        ],
        typing.Annotated[
            types.account.WallPapersNotModified,
            pydantic.Tag('account.WallPapersNotModified'),
            pydantic.Tag('WallPapersNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetGroupParticipants(BaseModel):
    """
    functions.phone.GetGroupParticipants
    ID: 0xc558d8ab
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.GetGroupParticipants', 'GetGroupParticipants'] = pydantic.Field(
        'functions.phone.GetGroupParticipants',
        alias='_'
    )

    call: "base.InputGroupCall"
    ids: list["base.InputPeer"]
    sources: list[int]
    offset: str
    limit: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputKeyboardButtonRequestPeer(BaseModel):
    """
    types.InputKeyboardButtonRequestPeer
    ID: 0xc9662d05
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputKeyboardButtonRequestPeer', 'InputKeyboardButtonRequestPeer'] = pydantic.Field(
        'types.InputKeyboardButtonRequestPeer',
        alias='_'
    )

    text: str
    button_id: int
    peer_type: "base.RequestPeerType"
    max_quantity: int
    name_requested: typing.Optional[bool] = None
    username_requested: typing.Optional[bool] = None
    photo_requested: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebPageAttributeStickerSet(BaseModel):
    """
    types.WebPageAttributeStickerSet
    ID: 0x50cc03d3
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WebPageAttributeStickerSet', 'WebPageAttributeStickerSet'] = pydantic.Field(
        'types.WebPageAttributeStickerSet',
        alias='_'
    )

    stickers: list["base.Document"]
    emojis: typing.Optional[bool] = None
    text_color: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputStickerSetItem(BaseModel):
    """
    types.InputStickerSetItem
    ID: 0x32da9e9c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputStickerSetItem', 'InputStickerSetItem'] = pydantic.Field(
        'types.InputStickerSetItem',
        alias='_'
    )

    document: "base.InputDocument"
    emoji: str
    mask_coords: typing.Optional["base.MaskCoords"] = None
    keywords: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetInlineBotResults(BaseModel):
    """
    functions.messages.SetInlineBotResults
    ID: 0xbb12a419
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SetInlineBotResults', 'SetInlineBotResults'] = pydantic.Field(
        'functions.messages.SetInlineBotResults',
        alias='_'
    )

    query_id: int
    results: list["base.InputBotInlineResult"]
    cache_time: int
    gallery: typing.Optional[bool] = None
    private: typing.Optional[bool] = None
    next_offset: typing.Optional[str] = None
    switch_pm: typing.Optional["base.InlineBotSwitchPM"] = None
    switch_webview: typing.Optional["base.InlineBotWebView"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PublicForwards(BaseModel):
    """
    types.stats.PublicForwards
    ID: 0x93037e20
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stats.PublicForwards', 'PublicForwards'] = pydantic.Field(
        'types.stats.PublicForwards',
        alias='_'
    )

    count: int
    forwards: list["base.PublicForward"]
    chats: list["base.Chat"]
    users: list["base.User"]
    next_offset: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.SavedGifs - Layer 181
SavedGifs = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.SavedGifs,
            pydantic.Tag('messages.SavedGifs'),
            pydantic.Tag('SavedGifs')
        ],
        typing.Annotated[
            types.messages.SavedGifsNotModified,
            pydantic.Tag('messages.SavedGifsNotModified'),
            pydantic.Tag('SavedGifsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetWebFile(BaseModel):
    """
    functions.upload.GetWebFile
    ID: 0x24e6818d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.upload.GetWebFile', 'GetWebFile'] = pydantic.Field(
        'functions.upload.GetWebFile',
        alias='_'
    )

    location: "base.InputWebFileLocation"
    offset: int
    limit: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class LangPackDifference(BaseModel):
    """
    types.LangPackDifference
    ID: 0xf385c1f6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.LangPackDifference', 'LangPackDifference'] = pydantic.Field(
        'types.LangPackDifference',
        alias='_'
    )

    lang_code: str
    from_version: int
    version: int
    strings: list["base.LangPackString"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EmailVerification - Layer 181
EmailVerification = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.EmailVerificationApple,
            pydantic.Tag('EmailVerificationApple')
        ],
        typing.Annotated[
            types.EmailVerificationCode,
            pydantic.Tag('EmailVerificationCode')
        ],
        typing.Annotated[
            types.EmailVerificationGoogle,
            pydantic.Tag('EmailVerificationGoogle')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AutoDownloadSettings(BaseModel):
    """
    types.account.AutoDownloadSettings
    ID: 0x63cacf26
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.AutoDownloadSettings', 'AutoDownloadSettings'] = pydantic.Field(
        'types.account.AutoDownloadSettings',
        alias='_'
    )

    low: "base.AutoDownloadSettings"
    medium: "base.AutoDownloadSettings"
    high: "base.AutoDownloadSettings"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestFirebaseSms(BaseModel):
    """
    functions.auth.RequestFirebaseSms
    ID: 0x8e39261e
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.RequestFirebaseSms', 'RequestFirebaseSms'] = pydantic.Field(
        'functions.auth.RequestFirebaseSms',
        alias='_'
    )

    phone_number: str
    phone_code_hash: str
    safety_net_token: typing.Optional[str] = None
    play_integrity_token: typing.Optional[str] = None
    ios_push_secret: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SendMessageAction - Layer 181
SendMessageAction = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.SendMessageCancelAction,
            pydantic.Tag('SendMessageCancelAction')
        ],
        typing.Annotated[
            types.SendMessageChooseContactAction,
            pydantic.Tag('SendMessageChooseContactAction')
        ],
        typing.Annotated[
            types.SendMessageChooseStickerAction,
            pydantic.Tag('SendMessageChooseStickerAction')
        ],
        typing.Annotated[
            types.SendMessageEmojiInteraction,
            pydantic.Tag('SendMessageEmojiInteraction')
        ],
        typing.Annotated[
            types.SendMessageEmojiInteractionSeen,
            pydantic.Tag('SendMessageEmojiInteractionSeen')
        ],
        typing.Annotated[
            types.SendMessageGamePlayAction,
            pydantic.Tag('SendMessageGamePlayAction')
        ],
        typing.Annotated[
            types.SendMessageGeoLocationAction,
            pydantic.Tag('SendMessageGeoLocationAction')
        ],
        typing.Annotated[
            types.SendMessageHistoryImportAction,
            pydantic.Tag('SendMessageHistoryImportAction')
        ],
        typing.Annotated[
            types.SendMessageRecordAudioAction,
            pydantic.Tag('SendMessageRecordAudioAction')
        ],
        typing.Annotated[
            types.SendMessageRecordRoundAction,
            pydantic.Tag('SendMessageRecordRoundAction')
        ],
        typing.Annotated[
            types.SendMessageRecordVideoAction,
            pydantic.Tag('SendMessageRecordVideoAction')
        ],
        typing.Annotated[
            types.SendMessageTypingAction,
            pydantic.Tag('SendMessageTypingAction')
        ],
        typing.Annotated[
            types.SendMessageUploadAudioAction,
            pydantic.Tag('SendMessageUploadAudioAction')
        ],
        typing.Annotated[
            types.SendMessageUploadDocumentAction,
            pydantic.Tag('SendMessageUploadDocumentAction')
        ],
        typing.Annotated[
            types.SendMessageUploadPhotoAction,
            pydantic.Tag('SendMessageUploadPhotoAction')
        ],
        typing.Annotated[
            types.SendMessageUploadRoundAction,
            pydantic.Tag('SendMessageUploadRoundAction')
        ],
        typing.Annotated[
            types.SendMessageUploadVideoAction,
            pydantic.Tag('SendMessageUploadVideoAction')
        ],
        typing.Annotated[
            types.SpeakingInGroupCallAction,
            pydantic.Tag('SpeakingInGroupCallAction')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BroadcastRevenueBalances(BaseModel):
    """
    types.BroadcastRevenueBalances
    ID: 0x8438f1c6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BroadcastRevenueBalances', 'BroadcastRevenueBalances'] = pydantic.Field(
        'types.BroadcastRevenueBalances',
        alias='_'
    )

    current_balance: int
    available_balance: int
    overall_revenue: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.LoginToken - Layer 181
LoginToken = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.auth.LoginToken,
            pydantic.Tag('auth.LoginToken'),
            pydantic.Tag('LoginToken')
        ],
        typing.Annotated[
            types.auth.LoginTokenMigrateTo,
            pydantic.Tag('auth.LoginTokenMigrateTo'),
            pydantic.Tag('LoginTokenMigrateTo')
        ],
        typing.Annotated[
            types.auth.LoginTokenSuccess,
            pydantic.Tag('auth.LoginTokenSuccess'),
            pydantic.Tag('LoginTokenSuccess')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CreateStickerSet(BaseModel):
    """
    functions.stickers.CreateStickerSet
    ID: 0x9021ab67
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stickers.CreateStickerSet', 'CreateStickerSet'] = pydantic.Field(
        'functions.stickers.CreateStickerSet',
        alias='_'
    )

    user_id: "base.InputUser"
    title: str
    short_name: str
    stickers: list["base.InputStickerSetItem"]
    masks: typing.Optional[bool] = None
    emojis: typing.Optional[bool] = None
    text_color: typing.Optional[bool] = None
    thumb: typing.Optional["base.InputDocument"] = None
    software: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# contacts.Contacts - Layer 181
Contacts = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.contacts.Contacts,
            pydantic.Tag('contacts.Contacts'),
            pydantic.Tag('Contacts')
        ],
        typing.Annotated[
            types.contacts.ContactsNotModified,
            pydantic.Tag('contacts.ContactsNotModified'),
            pydantic.Tag('ContactsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SaveTheme(BaseModel):
    """
    functions.account.SaveTheme
    ID: 0xf257106c
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.SaveTheme', 'SaveTheme'] = pydantic.Field(
        'functions.account.SaveTheme',
        alias='_'
    )

    theme: "base.InputTheme"
    unsave: bool



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ReportReason - Layer 181
ReportReason = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputReportReasonChildAbuse,
            pydantic.Tag('InputReportReasonChildAbuse')
        ],
        typing.Annotated[
            types.InputReportReasonCopyright,
            pydantic.Tag('InputReportReasonCopyright')
        ],
        typing.Annotated[
            types.InputReportReasonFake,
            pydantic.Tag('InputReportReasonFake')
        ],
        typing.Annotated[
            types.InputReportReasonGeoIrrelevant,
            pydantic.Tag('InputReportReasonGeoIrrelevant')
        ],
        typing.Annotated[
            types.InputReportReasonIllegalDrugs,
            pydantic.Tag('InputReportReasonIllegalDrugs')
        ],
        typing.Annotated[
            types.InputReportReasonOther,
            pydantic.Tag('InputReportReasonOther')
        ],
        typing.Annotated[
            types.InputReportReasonPersonalDetails,
            pydantic.Tag('InputReportReasonPersonalDetails')
        ],
        typing.Annotated[
            types.InputReportReasonPornography,
            pydantic.Tag('InputReportReasonPornography')
        ],
        typing.Annotated[
            types.InputReportReasonSpam,
            pydantic.Tag('InputReportReasonSpam')
        ],
        typing.Annotated[
            types.InputReportReasonViolence,
            pydantic.Tag('InputReportReasonViolence')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000(BaseModel):
    """
    types.SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000
    ID: 0xbbf2dda0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000', 'SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000'] = pydantic.Field(
        'types.SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000',
        alias='_'
    )

    salt: Bytes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageTableCell(BaseModel):
    """
    types.PageTableCell
    ID: 0x34566b6a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageTableCell', 'PageTableCell'] = pydantic.Field(
        'types.PageTableCell',
        alias='_'
    )

    header: typing.Optional[bool] = None
    align_center: typing.Optional[bool] = None
    align_right: typing.Optional[bool] = None
    valign_middle: typing.Optional[bool] = None
    valign_bottom: typing.Optional[bool] = None
    text: typing.Optional["base.RichText"] = None
    colspan: typing.Optional[int] = None
    rowspan: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# NotifyPeer - Layer 181
NotifyPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.NotifyBroadcasts,
            pydantic.Tag('NotifyBroadcasts')
        ],
        typing.Annotated[
            types.NotifyChats,
            pydantic.Tag('NotifyChats')
        ],
        typing.Annotated[
            types.NotifyForumTopic,
            pydantic.Tag('NotifyForumTopic')
        ],
        typing.Annotated[
            types.NotifyPeer,
            pydantic.Tag('NotifyPeer')
        ],
        typing.Annotated[
            types.NotifyUsers,
            pydantic.Tag('NotifyUsers')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DiscussionMessage(BaseModel):
    """
    types.messages.DiscussionMessage
    ID: 0xa6341782
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.DiscussionMessage', 'DiscussionMessage'] = pydantic.Field(
        'types.messages.DiscussionMessage',
        alias='_'
    )

    messages: list["base.Message"]
    unread_count: int
    chats: list["base.Chat"]
    users: list["base.User"]
    max_id: typing.Optional[int] = None
    read_inbox_max_id: typing.Optional[int] = None
    read_outbox_max_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotApp(BaseModel):
    """
    types.messages.BotApp
    ID: 0xeb50adf5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.BotApp', 'BotApp'] = pydantic.Field(
        'types.messages.BotApp',
        alias='_'
    )

    app: "base.BotApp"
    inactive: typing.Optional[bool] = None
    request_write_access: typing.Optional[bool] = None
    has_settings: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputInvoicePremiumGiftCode(BaseModel):
    """
    types.InputInvoicePremiumGiftCode
    ID: 0x98986c0d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputInvoicePremiumGiftCode', 'InputInvoicePremiumGiftCode'] = pydantic.Field(
        'types.InputInvoicePremiumGiftCode',
        alias='_'
    )

    purpose: "base.InputStorePaymentPurpose"
    option: "base.PremiumGiftCodeOption"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SecureValueType - Layer 181
SecureValueType = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.SecureValueTypeAddress,
            pydantic.Tag('SecureValueTypeAddress')
        ],
        typing.Annotated[
            types.SecureValueTypeBankStatement,
            pydantic.Tag('SecureValueTypeBankStatement')
        ],
        typing.Annotated[
            types.SecureValueTypeDriverLicense,
            pydantic.Tag('SecureValueTypeDriverLicense')
        ],
        typing.Annotated[
            types.SecureValueTypeEmail,
            pydantic.Tag('SecureValueTypeEmail')
        ],
        typing.Annotated[
            types.SecureValueTypeIdentityCard,
            pydantic.Tag('SecureValueTypeIdentityCard')
        ],
        typing.Annotated[
            types.SecureValueTypeInternalPassport,
            pydantic.Tag('SecureValueTypeInternalPassport')
        ],
        typing.Annotated[
            types.SecureValueTypePassport,
            pydantic.Tag('SecureValueTypePassport')
        ],
        typing.Annotated[
            types.SecureValueTypePassportRegistration,
            pydantic.Tag('SecureValueTypePassportRegistration')
        ],
        typing.Annotated[
            types.SecureValueTypePersonalDetails,
            pydantic.Tag('SecureValueTypePersonalDetails')
        ],
        typing.Annotated[
            types.SecureValueTypePhone,
            pydantic.Tag('SecureValueTypePhone')
        ],
        typing.Annotated[
            types.SecureValueTypeRentalAgreement,
            pydantic.Tag('SecureValueTypeRentalAgreement')
        ],
        typing.Annotated[
            types.SecureValueTypeTemporaryRegistration,
            pydantic.Tag('SecureValueTypeTemporaryRegistration')
        ],
        typing.Annotated[
            types.SecureValueTypeUtilityBill,
            pydantic.Tag('SecureValueTypeUtilityBill')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReactionCount(BaseModel):
    """
    types.ReactionCount
    ID: 0xa3d1cb80
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ReactionCount', 'ReactionCount'] = pydantic.Field(
        'types.ReactionCount',
        alias='_'
    )

    reaction: "base.Reaction"
    count: int
    chosen_order: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaGeoLive(BaseModel):
    """
    types.MessageMediaGeoLive
    ID: 0xb940c666
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaGeoLive', 'MessageMediaGeoLive'] = pydantic.Field(
        'types.MessageMediaGeoLive',
        alias='_'
    )

    geo: "base.GeoPoint"
    period: int
    heading: typing.Optional[int] = None
    proximity_notification_radius: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SecureValueError - Layer 181
SecureValueError = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.SecureValueError,
            pydantic.Tag('SecureValueError')
        ],
        typing.Annotated[
            types.SecureValueErrorData,
            pydantic.Tag('SecureValueErrorData')
        ],
        typing.Annotated[
            types.SecureValueErrorFile,
            pydantic.Tag('SecureValueErrorFile')
        ],
        typing.Annotated[
            types.SecureValueErrorFiles,
            pydantic.Tag('SecureValueErrorFiles')
        ],
        typing.Annotated[
            types.SecureValueErrorFrontSide,
            pydantic.Tag('SecureValueErrorFrontSide')
        ],
        typing.Annotated[
            types.SecureValueErrorReverseSide,
            pydantic.Tag('SecureValueErrorReverseSide')
        ],
        typing.Annotated[
            types.SecureValueErrorSelfie,
            pydantic.Tag('SecureValueErrorSelfie')
        ],
        typing.Annotated[
            types.SecureValueErrorTranslationFile,
            pydantic.Tag('SecureValueErrorTranslationFile')
        ],
        typing.Annotated[
            types.SecureValueErrorTranslationFiles,
            pydantic.Tag('SecureValueErrorTranslationFiles')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPeer - Layer 181
InputPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputPeerChannel,
            pydantic.Tag('InputPeerChannel')
        ],
        typing.Annotated[
            types.InputPeerChannelFromMessage,
            pydantic.Tag('InputPeerChannelFromMessage')
        ],
        typing.Annotated[
            types.InputPeerChat,
            pydantic.Tag('InputPeerChat')
        ],
        typing.Annotated[
            types.InputPeerEmpty,
            pydantic.Tag('InputPeerEmpty')
        ],
        typing.Annotated[
            types.InputPeerSelf,
            pydantic.Tag('InputPeerSelf')
        ],
        typing.Annotated[
            types.InputPeerUser,
            pydantic.Tag('InputPeerUser')
        ],
        typing.Annotated[
            types.InputPeerUserFromMessage,
            pydantic.Tag('InputPeerUserFromMessage')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.SavedReactionTags - Layer 181
SavedReactionTags = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.SavedReactionTags,
            pydantic.Tag('messages.SavedReactionTags'),
            pydantic.Tag('SavedReactionTags')
        ],
        typing.Annotated[
            types.messages.SavedReactionTagsNotModified,
            pydantic.Tag('messages.SavedReactionTagsNotModified'),
            pydantic.Tag('SavedReactionTagsNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SecureRequiredType(BaseModel):
    """
    types.SecureRequiredType
    ID: 0x829d99da
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SecureRequiredType', 'SecureRequiredType'] = pydantic.Field(
        'types.SecureRequiredType',
        alias='_'
    )

    type: "base.SecureValueType"
    native_names: typing.Optional[bool] = None
    selfie_required: typing.Optional[bool] = None
    translation_required: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPrivacyKey - Layer 181
InputPrivacyKey = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputPrivacyKeyAbout,
            pydantic.Tag('InputPrivacyKeyAbout')
        ],
        typing.Annotated[
            types.InputPrivacyKeyAddedByPhone,
            pydantic.Tag('InputPrivacyKeyAddedByPhone')
        ],
        typing.Annotated[
            types.InputPrivacyKeyBirthday,
            pydantic.Tag('InputPrivacyKeyBirthday')
        ],
        typing.Annotated[
            types.InputPrivacyKeyChatInvite,
            pydantic.Tag('InputPrivacyKeyChatInvite')
        ],
        typing.Annotated[
            types.InputPrivacyKeyForwards,
            pydantic.Tag('InputPrivacyKeyForwards')
        ],
        typing.Annotated[
            types.InputPrivacyKeyPhoneCall,
            pydantic.Tag('InputPrivacyKeyPhoneCall')
        ],
        typing.Annotated[
            types.InputPrivacyKeyPhoneNumber,
            pydantic.Tag('InputPrivacyKeyPhoneNumber')
        ],
        typing.Annotated[
            types.InputPrivacyKeyPhoneP2P,
            pydantic.Tag('InputPrivacyKeyPhoneP2P')
        ],
        typing.Annotated[
            types.InputPrivacyKeyProfilePhoto,
            pydantic.Tag('InputPrivacyKeyProfilePhoto')
        ],
        typing.Annotated[
            types.InputPrivacyKeyStatusTimestamp,
            pydantic.Tag('InputPrivacyKeyStatusTimestamp')
        ],
        typing.Annotated[
            types.InputPrivacyKeyVoiceMessages,
            pydantic.Tag('InputPrivacyKeyVoiceMessages')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatInvitePeek(BaseModel):
    """
    types.ChatInvitePeek
    ID: 0x61695cb0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatInvitePeek', 'ChatInvitePeek'] = pydantic.Field(
        'types.ChatInvitePeek',
        alias='_'
    )

    chat: "base.Chat"
    expires: Datetime



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StatsAbsValueAndPrev(BaseModel):
    """
    types.StatsAbsValueAndPrev
    ID: 0xcb43acde
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StatsAbsValueAndPrev', 'StatsAbsValueAndPrev'] = pydantic.Field(
        'types.StatsAbsValueAndPrev',
        alias='_'
    )

    current: float
    previous: float



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateInlineBotCallbackQuery(BaseModel):
    """
    types.UpdateInlineBotCallbackQuery
    ID: 0x691e9052
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateInlineBotCallbackQuery', 'UpdateInlineBotCallbackQuery'] = pydantic.Field(
        'types.UpdateInlineBotCallbackQuery',
        alias='_'
    )

    query_id: int
    user_id: int
    msg_id: "base.InputBotInlineMessageID"
    chat_instance: int
    data: typing.Optional[Bytes] = None
    game_short_name: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetChannelDifference(BaseModel):
    """
    functions.updates.GetChannelDifference
    ID: 0x3173d78
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.updates.GetChannelDifference', 'GetChannelDifference'] = pydantic.Field(
        'functions.updates.GetChannelDifference',
        alias='_'
    )

    channel: "base.InputChannel"
    filter: "base.ChannelMessagesFilter"
    pts: int
    limit: int
    force: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.Dialogs - Layer 181
Dialogs = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.Dialogs,
            pydantic.Tag('messages.Dialogs'),
            pydantic.Tag('Dialogs')
        ],
        typing.Annotated[
            types.messages.DialogsNotModified,
            pydantic.Tag('messages.DialogsNotModified'),
            pydantic.Tag('DialogsNotModified')
        ],
        typing.Annotated[
            types.messages.DialogsSlice,
            pydantic.Tag('messages.DialogsSlice'),
            pydantic.Tag('DialogsSlice')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateMessagePollVote(BaseModel):
    """
    types.UpdateMessagePollVote
    ID: 0x24f40e77
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateMessagePollVote', 'UpdateMessagePollVote'] = pydantic.Field(
        'types.UpdateMessagePollVote',
        alias='_'
    )

    poll_id: int
    peer: "base.Peer"
    options: list[Bytes]
    qts: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputBotInlineResult - Layer 181
InputBotInlineResult = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputBotInlineResult,
            pydantic.Tag('InputBotInlineResult')
        ],
        typing.Annotated[
            types.InputBotInlineResultDocument,
            pydantic.Tag('InputBotInlineResultDocument')
        ],
        typing.Annotated[
            types.InputBotInlineResultGame,
            pydantic.Tag('InputBotInlineResultGame')
        ],
        typing.Annotated[
            types.InputBotInlineResultPhoto,
            pydantic.Tag('InputBotInlineResultPhoto')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DocumentAttributeCustomEmoji(BaseModel):
    """
    types.DocumentAttributeCustomEmoji
    ID: 0xfd149899
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DocumentAttributeCustomEmoji', 'DocumentAttributeCustomEmoji'] = pydantic.Field(
        'types.DocumentAttributeCustomEmoji',
        alias='_'
    )

    alt: str
    stickerset: "base.InputStickerSet"
    free: typing.Optional[bool] = None
    text_color: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Updates - Layer 181
Updates = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.UpdateShort,
            pydantic.Tag('UpdateShort')
        ],
        typing.Annotated[
            types.UpdateShortChatMessage,
            pydantic.Tag('UpdateShortChatMessage')
        ],
        typing.Annotated[
            types.UpdateShortMessage,
            pydantic.Tag('UpdateShortMessage')
        ],
        typing.Annotated[
            types.UpdateShortSentMessage,
            pydantic.Tag('UpdateShortSentMessage')
        ],
        typing.Annotated[
            types.Updates,
            pydantic.Tag('Updates')
        ],
        typing.Annotated[
            types.UpdatesCombined,
            pydantic.Tag('UpdatesCombined')
        ],
        typing.Annotated[
            types.UpdatesTooLong,
            pydantic.Tag('UpdatesTooLong')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StatsGroupTopAdmin(BaseModel):
    """
    types.StatsGroupTopAdmin
    ID: 0xd7584c87
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StatsGroupTopAdmin', 'StatsGroupTopAdmin'] = pydantic.Field(
        'types.StatsGroupTopAdmin',
        alias='_'
    )

    user_id: int
    deleted: int
    kicked: int
    banned: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BroadcastRevenueTransaction - Layer 181
BroadcastRevenueTransaction = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.BroadcastRevenueTransactionProceeds,
            pydantic.Tag('BroadcastRevenueTransactionProceeds')
        ],
        typing.Annotated[
            types.BroadcastRevenueTransactionRefund,
            pydantic.Tag('BroadcastRevenueTransactionRefund')
        ],
        typing.Annotated[
            types.BroadcastRevenueTransactionWithdrawal,
            pydantic.Tag('BroadcastRevenueTransactionWithdrawal')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Stickers(BaseModel):
    """
    types.messages.Stickers
    ID: 0x30a6ec7e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.Stickers', 'Stickers'] = pydantic.Field(
        'types.messages.Stickers',
        alias='_'
    )

    hash: int
    stickers: list["base.Document"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventActionPinTopic(BaseModel):
    """
    types.ChannelAdminLogEventActionPinTopic
    ID: 0x5d8d353b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventActionPinTopic', 'ChannelAdminLogEventActionPinTopic'] = pydantic.Field(
        'types.ChannelAdminLogEventActionPinTopic',
        alias='_'
    )

    prev_topic: typing.Optional["base.ForumTopic"] = None
    new_topic: typing.Optional["base.ForumTopic"] = None



from .channel_participants import ChannelParticipants
from .channel_participant import ChannelParticipant
from .admin_log_results import AdminLogResults
from .send_as_peers import SendAsPeers
from .sponsored_message_report_result import SponsoredMessageReportResult



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateShortSentMessage(BaseModel):
    """
    types.UpdateShortSentMessage
    ID: 0x9015e101
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateShortSentMessage', 'UpdateShortSentMessage'] = pydantic.Field(
        'types.UpdateShortSentMessage',
        alias='_'
    )

    id: int
    pts: int
    pts_count: int
    date: Datetime
    out: typing.Optional[bool] = None
    media: typing.Optional["base.MessageMedia"] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None
    ttl_period: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SearchSentMedia(BaseModel):
    """
    functions.messages.SearchSentMedia
    ID: 0x107e31a0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SearchSentMedia', 'SearchSentMedia'] = pydantic.Field(
        'functions.messages.SearchSentMedia',
        alias='_'
    )

    q: str
    filter: "base.MessagesFilter"
    limit: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# WebPage - Layer 181
WebPage = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.WebPage,
            pydantic.Tag('WebPage')
        ],
        typing.Annotated[
            types.WebPageEmpty,
            pydantic.Tag('WebPageEmpty')
        ],
        typing.Annotated[
            types.WebPageNotModified,
            pydantic.Tag('WebPageNotModified')
        ],
        typing.Annotated[
            types.WebPagePending,
            pydantic.Tag('WebPagePending')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class TopPeers(BaseModel):
    """
    types.contacts.TopPeers
    ID: 0x70b772a8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.contacts.TopPeers', 'TopPeers'] = pydantic.Field(
        'types.contacts.TopPeers',
        alias='_'
    )

    categories: list["base.TopPeerCategoryPeers"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# TopPeerCategory - Layer 181
TopPeerCategory = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.TopPeerCategoryBotsInline,
            pydantic.Tag('TopPeerCategoryBotsInline')
        ],
        typing.Annotated[
            types.TopPeerCategoryBotsPM,
            pydantic.Tag('TopPeerCategoryBotsPM')
        ],
        typing.Annotated[
            types.TopPeerCategoryChannels,
            pydantic.Tag('TopPeerCategoryChannels')
        ],
        typing.Annotated[
            types.TopPeerCategoryCorrespondents,
            pydantic.Tag('TopPeerCategoryCorrespondents')
        ],
        typing.Annotated[
            types.TopPeerCategoryForwardChats,
            pydantic.Tag('TopPeerCategoryForwardChats')
        ],
        typing.Annotated[
            types.TopPeerCategoryForwardUsers,
            pydantic.Tag('TopPeerCategoryForwardUsers')
        ],
        typing.Annotated[
            types.TopPeerCategoryGroups,
            pydantic.Tag('TopPeerCategoryGroups')
        ],
        typing.Annotated[
            types.TopPeerCategoryPhoneCalls,
            pydantic.Tag('TopPeerCategoryPhoneCalls')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BotMenuButton - Layer 181
BotMenuButton = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.BotMenuButton,
            pydantic.Tag('BotMenuButton')
        ],
        typing.Annotated[
            types.BotMenuButtonCommands,
            pydantic.Tag('BotMenuButtonCommands')
        ],
        typing.Annotated[
            types.BotMenuButtonDefault,
            pydantic.Tag('BotMenuButtonDefault')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateFolderPeers(BaseModel):
    """
    types.UpdateFolderPeers
    ID: 0x19360dc0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateFolderPeers', 'UpdateFolderPeers'] = pydantic.Field(
        'types.UpdateFolderPeers',
        alias='_'
    )

    folder_peers: list["base.FolderPeer"]
    pts: int
    pts_count: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DialogFilter(BaseModel):
    """
    types.DialogFilter
    ID: 0x5fb5523b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DialogFilter', 'DialogFilter'] = pydantic.Field(
        'types.DialogFilter',
        alias='_'
    )

    id: int
    title: str
    pinned_peers: list["base.InputPeer"]
    include_peers: list["base.InputPeer"]
    exclude_peers: list["base.InputPeer"]
    contacts: typing.Optional[bool] = None
    non_contacts: typing.Optional[bool] = None
    groups: typing.Optional[bool] = None
    broadcasts: typing.Optional[bool] = None
    bots: typing.Optional[bool] = None
    exclude_muted: typing.Optional[bool] = None
    exclude_read: typing.Optional[bool] = None
    exclude_archived: typing.Optional[bool] = None
    emoticon: typing.Optional[str] = None
    color: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetWallPaper(BaseModel):
    """
    functions.account.GetWallPaper
    ID: 0xfc8ddbea
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.GetWallPaper', 'GetWallPaper'] = pydantic.Field(
        'functions.account.GetWallPaper',
        alias='_'
    )

    wallpaper: "base.InputWallPaper"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EditStory(BaseModel):
    """
    functions.stories.EditStory
    ID: 0xb583ba46
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stories.EditStory', 'EditStory'] = pydantic.Field(
        'functions.stories.EditStory',
        alias='_'
    )

    peer: "base.InputPeer"
    id: int
    media: typing.Optional["base.InputMedia"] = None
    media_areas: typing.Optional[list["base.MediaArea"]] = None
    caption: typing.Optional[str] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None
    privacy_rules: typing.Optional[list["base.InputPrivacyRule"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessagePeerReaction(BaseModel):
    """
    types.MessagePeerReaction
    ID: 0x8c79b63c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessagePeerReaction', 'MessagePeerReaction'] = pydantic.Field(
        'types.MessagePeerReaction',
        alias='_'
    )

    peer_id: "base.Peer"
    date: Datetime
    reaction: "base.Reaction"
    big: typing.Optional[bool] = None
    unread: typing.Optional[bool] = None
    my: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.DeepLinkInfo - Layer 181
DeepLinkInfo = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.help.DeepLinkInfo,
            pydantic.Tag('help.DeepLinkInfo'),
            pydantic.Tag('DeepLinkInfo')
        ],
        typing.Annotated[
            types.help.DeepLinkInfoEmpty,
            pydantic.Tag('help.DeepLinkInfoEmpty'),
            pydantic.Tag('DeepLinkInfoEmpty')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryFwdHeader(BaseModel):
    """
    types.StoryFwdHeader
    ID: 0xb826e150
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StoryFwdHeader', 'StoryFwdHeader'] = pydantic.Field(
        'types.StoryFwdHeader',
        alias='_'
    )

    modified: typing.Optional[bool] = None
    from_peer: typing.Optional["base.Peer"] = pydantic.Field(
        None,
        serialization_alias='from',
        validation_alias=pydantic.AliasChoices('from', 'from_peer', 'from_')
    )
    from_name: typing.Optional[str] = None
    story_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatAdminsWithInvites(BaseModel):
    """
    types.messages.ChatAdminsWithInvites
    ID: 0xb69b72d7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.ChatAdminsWithInvites', 'ChatAdminsWithInvites'] = pydantic.Field(
        'types.messages.ChatAdminsWithInvites',
        alias='_'
    )

    admins: list["base.ChatAdminWithInvites"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PostInteractionCounters - Layer 181
PostInteractionCounters = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PostInteractionCountersMessage,
            pydantic.Tag('PostInteractionCountersMessage')
        ],
        typing.Annotated[
            types.PostInteractionCountersStory,
            pydantic.Tag('PostInteractionCountersStory')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaWebPage(BaseModel):
    """
    types.MessageMediaWebPage
    ID: 0xddf10c3b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaWebPage', 'MessageMediaWebPage'] = pydantic.Field(
        'types.MessageMediaWebPage',
        alias='_'
    )

    webpage: "base.WebPage"
    force_large_media: typing.Optional[bool] = None
    force_small_media: typing.Optional[bool] = None
    manual: typing.Optional[bool] = None
    safe: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaContact(BaseModel):
    """
    types.InputMediaContact
    ID: 0xf8ab7dfb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaContact', 'InputMediaContact'] = pydantic.Field(
        'types.InputMediaContact',
        alias='_'
    )

    phone_number: str
    first_name: str
    last_name: str
    vcard: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ReplyMarkup - Layer 181
ReplyMarkup = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ReplyInlineMarkup,
            pydantic.Tag('ReplyInlineMarkup')
        ],
        typing.Annotated[
            types.ReplyKeyboardForceReply,
            pydantic.Tag('ReplyKeyboardForceReply')
        ],
        typing.Annotated[
            types.ReplyKeyboardHide,
            pydantic.Tag('ReplyKeyboardHide')
        ],
        typing.Annotated[
            types.ReplyKeyboardMarkup,
            pydantic.Tag('ReplyKeyboardMarkup')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChatParticipant - Layer 181
ChatParticipant = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ChatParticipant,
            pydantic.Tag('ChatParticipant')
        ],
        typing.Annotated[
            types.ChatParticipantAdmin,
            pydantic.Tag('ChatParticipantAdmin')
        ],
        typing.Annotated[
            types.ChatParticipantCreator,
            pydantic.Tag('ChatParticipantCreator')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StatsGraph(BaseModel):
    """
    types.StatsGraph
    ID: 0x8ea464b6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StatsGraph', 'StatsGraph'] = pydantic.Field(
        'types.StatsGraph',
        alias='_'
    )

    json_: "base.DataJSON" = pydantic.Field(
        ...,
        serialization_alias='json',
        validation_alias=pydantic.AliasChoices('json', 'json_')
    )
    zoom_token: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateReadChannelInbox(BaseModel):
    """
    types.UpdateReadChannelInbox
    ID: 0x922e6e10
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateReadChannelInbox', 'UpdateReadChannelInbox'] = pydantic.Field(
        'types.UpdateReadChannelInbox',
        alias='_'
    )

    channel_id: int
    max_id: int
    still_unread_count: int
    pts: int
    folder_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PrivacyRule - Layer 181
PrivacyRule = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PrivacyValueAllowAll,
            pydantic.Tag('PrivacyValueAllowAll')
        ],
        typing.Annotated[
            types.PrivacyValueAllowChatParticipants,
            pydantic.Tag('PrivacyValueAllowChatParticipants')
        ],
        typing.Annotated[
            types.PrivacyValueAllowCloseFriends,
            pydantic.Tag('PrivacyValueAllowCloseFriends')
        ],
        typing.Annotated[
            types.PrivacyValueAllowContacts,
            pydantic.Tag('PrivacyValueAllowContacts')
        ],
        typing.Annotated[
            types.PrivacyValueAllowPremium,
            pydantic.Tag('PrivacyValueAllowPremium')
        ],
        typing.Annotated[
            types.PrivacyValueAllowUsers,
            pydantic.Tag('PrivacyValueAllowUsers')
        ],
        typing.Annotated[
            types.PrivacyValueDisallowAll,
            pydantic.Tag('PrivacyValueDisallowAll')
        ],
        typing.Annotated[
            types.PrivacyValueDisallowChatParticipants,
            pydantic.Tag('PrivacyValueDisallowChatParticipants')
        ],
        typing.Annotated[
            types.PrivacyValueDisallowContacts,
            pydantic.Tag('PrivacyValueDisallowContacts')
        ],
        typing.Annotated[
            types.PrivacyValueDisallowUsers,
            pydantic.Tag('PrivacyValueDisallowUsers')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AttachMenuBot(BaseModel):
    """
    types.AttachMenuBot
    ID: 0xd90d8dfe
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AttachMenuBot', 'AttachMenuBot'] = pydantic.Field(
        'types.AttachMenuBot',
        alias='_'
    )

    bot_id: int
    short_name: str
    icons: list["base.AttachMenuBotIcon"]
    inactive: typing.Optional[bool] = None
    has_settings: typing.Optional[bool] = None
    request_write_access: typing.Optional[bool] = None
    show_in_attach_menu: typing.Optional[bool] = None
    show_in_side_menu: typing.Optional[bool] = None
    side_menu_disclaimer_needed: typing.Optional[bool] = None
    peer_types: typing.Optional[list["base.AttachMenuPeerType"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputInvoice - Layer 181
InputInvoice = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputInvoiceMessage,
            pydantic.Tag('InputInvoiceMessage')
        ],
        typing.Annotated[
            types.InputInvoicePremiumGiftCode,
            pydantic.Tag('InputInvoicePremiumGiftCode')
        ],
        typing.Annotated[
            types.InputInvoiceSlug,
            pydantic.Tag('InputInvoiceSlug')
        ],
        typing.Annotated[
            types.InputInvoiceStars,
            pydantic.Tag('InputInvoiceStars')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateSettings(BaseModel):
    """
    functions.smsjobs.UpdateSettings
    ID: 0x93fa0bf
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.smsjobs.UpdateSettings', 'UpdateSettings'] = pydantic.Field(
        'functions.smsjobs.UpdateSettings',
        alias='_'
    )

    allow_international: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SavedDialog(BaseModel):
    """
    types.SavedDialog
    ID: 0xbd87cb6c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SavedDialog', 'SavedDialog'] = pydantic.Field(
        'types.SavedDialog',
        alias='_'
    )

    peer: "base.Peer"
    top_message: int
    pinned: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BoostsList(BaseModel):
    """
    types.premium.BoostsList
    ID: 0x86f8613c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.premium.BoostsList', 'BoostsList'] = pydantic.Field(
        'types.premium.BoostsList',
        alias='_'
    )

    count: int
    boosts: list["base.Boost"]
    users: list["base.User"]
    next_offset: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetDefaultProfilePhotoEmojis(BaseModel):
    """
    functions.account.GetDefaultProfilePhotoEmojis
    ID: 0xe2750328
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.GetDefaultProfilePhotoEmojis', 'GetDefaultProfilePhotoEmojis'] = pydantic.Field(
        'functions.account.GetDefaultProfilePhotoEmojis',
        alias='_'
    )

    hash: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SponsoredMessage(BaseModel):
    """
    types.SponsoredMessage
    ID: 0xbdedf566
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SponsoredMessage', 'SponsoredMessage'] = pydantic.Field(
        'types.SponsoredMessage',
        alias='_'
    )

    random_id: Bytes
    url: str
    title: str
    message: str
    button_text: str
    recommended: typing.Optional[bool] = None
    can_report: typing.Optional[bool] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None
    photo: typing.Optional["base.Photo"] = None
    color: typing.Optional["base.PeerColor"] = None
    sponsor_info: typing.Optional[str] = None
    additional_info: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.PeerColorSet - Layer 181
PeerColorSet = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.help.PeerColorProfileSet,
            pydantic.Tag('help.PeerColorProfileSet'),
            pydantic.Tag('PeerColorProfileSet')
        ],
        typing.Annotated[
            types.help.PeerColorSet,
            pydantic.Tag('help.PeerColorSet'),
            pydantic.Tag('PeerColorSet')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# stories.AllStories - Layer 181
AllStories = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.stories.AllStories,
            pydantic.Tag('stories.AllStories'),
            pydantic.Tag('AllStories')
        ],
        typing.Annotated[
            types.stories.AllStoriesNotModified,
            pydantic.Tag('stories.AllStoriesNotModified'),
            pydantic.Tag('AllStoriesNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow(BaseModel):
    """
    types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow
    ID: 0x3a912d4a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow', 'PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow'] = pydantic.Field(
        'types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow',
        alias='_'
    )

    salt1: Bytes
    salt2: Bytes
    g: int
    p: Bytes



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.PromoData - Layer 181
PromoData = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.help.PromoData,
            pydantic.Tag('help.PromoData'),
            pydantic.Tag('PromoData')
        ],
        typing.Annotated[
            types.help.PromoDataEmpty,
            pydantic.Tag('help.PromoDataEmpty'),
            pydantic.Tag('PromoDataEmpty')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WallPaperSettings(BaseModel):
    """
    types.WallPaperSettings
    ID: 0x372efcd0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WallPaperSettings', 'WallPaperSettings'] = pydantic.Field(
        'types.WallPaperSettings',
        alias='_'
    )

    blur: typing.Optional[bool] = None
    motion: typing.Optional[bool] = None
    background_color: typing.Optional[int] = None
    second_background_color: typing.Optional[int] = None
    third_background_color: typing.Optional[int] = None
    fourth_background_color: typing.Optional[int] = None
    intensity: typing.Optional[int] = None
    rotation: typing.Optional[int] = None
    emoticon: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionPaymentSentMe(BaseModel):
    """
    types.MessageActionPaymentSentMe
    ID: 0x8f31b327
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionPaymentSentMe', 'MessageActionPaymentSentMe'] = pydantic.Field(
        'types.MessageActionPaymentSentMe',
        alias='_'
    )

    currency: str
    total_amount: int
    payload: Bytes
    charge: "base.PaymentCharge"
    recurring_init: typing.Optional[bool] = None
    recurring_used: typing.Optional[bool] = None
    info: typing.Optional["base.PaymentRequestedInfo"] = None
    shipping_option_id: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessageAction - Layer 181
MessageAction = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.MessageActionBoostApply,
            pydantic.Tag('MessageActionBoostApply')
        ],
        typing.Annotated[
            types.MessageActionBotAllowed,
            pydantic.Tag('MessageActionBotAllowed')
        ],
        typing.Annotated[
            types.MessageActionChannelCreate,
            pydantic.Tag('MessageActionChannelCreate')
        ],
        typing.Annotated[
            types.MessageActionChannelMigrateFrom,
            pydantic.Tag('MessageActionChannelMigrateFrom')
        ],
        typing.Annotated[
            types.MessageActionChatAddUser,
            pydantic.Tag('MessageActionChatAddUser')
        ],
        typing.Annotated[
            types.MessageActionChatCreate,
            pydantic.Tag('MessageActionChatCreate')
        ],
        typing.Annotated[
            types.MessageActionChatDeletePhoto,
            pydantic.Tag('MessageActionChatDeletePhoto')
        ],
        typing.Annotated[
            types.MessageActionChatDeleteUser,
            pydantic.Tag('MessageActionChatDeleteUser')
        ],
        typing.Annotated[
            types.MessageActionChatEditPhoto,
            pydantic.Tag('MessageActionChatEditPhoto')
        ],
        typing.Annotated[
            types.MessageActionChatEditTitle,
            pydantic.Tag('MessageActionChatEditTitle')
        ],
        typing.Annotated[
            types.MessageActionChatJoinedByLink,
            pydantic.Tag('MessageActionChatJoinedByLink')
        ],
        typing.Annotated[
            types.MessageActionChatJoinedByRequest,
            pydantic.Tag('MessageActionChatJoinedByRequest')
        ],
        typing.Annotated[
            types.MessageActionChatMigrateTo,
            pydantic.Tag('MessageActionChatMigrateTo')
        ],
        typing.Annotated[
            types.MessageActionContactSignUp,
            pydantic.Tag('MessageActionContactSignUp')
        ],
        typing.Annotated[
            types.MessageActionCustomAction,
            pydantic.Tag('MessageActionCustomAction')
        ],
        typing.Annotated[
            types.MessageActionEmpty,
            pydantic.Tag('MessageActionEmpty')
        ],
        typing.Annotated[
            types.MessageActionGameScore,
            pydantic.Tag('MessageActionGameScore')
        ],
        typing.Annotated[
            types.MessageActionGeoProximityReached,
            pydantic.Tag('MessageActionGeoProximityReached')
        ],
        typing.Annotated[
            types.MessageActionGiftCode,
            pydantic.Tag('MessageActionGiftCode')
        ],
        typing.Annotated[
            types.MessageActionGiftPremium,
            pydantic.Tag('MessageActionGiftPremium')
        ],
        typing.Annotated[
            types.MessageActionGiveawayLaunch,
            pydantic.Tag('MessageActionGiveawayLaunch')
        ],
        typing.Annotated[
            types.MessageActionGiveawayResults,
            pydantic.Tag('MessageActionGiveawayResults')
        ],
        typing.Annotated[
            types.MessageActionGroupCall,
            pydantic.Tag('MessageActionGroupCall')
        ],
        typing.Annotated[
            types.MessageActionGroupCallScheduled,
            pydantic.Tag('MessageActionGroupCallScheduled')
        ],
        typing.Annotated[
            types.MessageActionHistoryClear,
            pydantic.Tag('MessageActionHistoryClear')
        ],
        typing.Annotated[
            types.MessageActionInviteToGroupCall,
            pydantic.Tag('MessageActionInviteToGroupCall')
        ],
        typing.Annotated[
            types.MessageActionPaymentSent,
            pydantic.Tag('MessageActionPaymentSent')
        ],
        typing.Annotated[
            types.MessageActionPaymentSentMe,
            pydantic.Tag('MessageActionPaymentSentMe')
        ],
        typing.Annotated[
            types.MessageActionPhoneCall,
            pydantic.Tag('MessageActionPhoneCall')
        ],
        typing.Annotated[
            types.MessageActionPinMessage,
            pydantic.Tag('MessageActionPinMessage')
        ],
        typing.Annotated[
            types.MessageActionRequestedPeer,
            pydantic.Tag('MessageActionRequestedPeer')
        ],
        typing.Annotated[
            types.MessageActionRequestedPeerSentMe,
            pydantic.Tag('MessageActionRequestedPeerSentMe')
        ],
        typing.Annotated[
            types.MessageActionScreenshotTaken,
            pydantic.Tag('MessageActionScreenshotTaken')
        ],
        typing.Annotated[
            types.MessageActionSecureValuesSent,
            pydantic.Tag('MessageActionSecureValuesSent')
        ],
        typing.Annotated[
            types.MessageActionSecureValuesSentMe,
            pydantic.Tag('MessageActionSecureValuesSentMe')
        ],
        typing.Annotated[
            types.MessageActionSetChatTheme,
            pydantic.Tag('MessageActionSetChatTheme')
        ],
        typing.Annotated[
            types.MessageActionSetChatWallPaper,
            pydantic.Tag('MessageActionSetChatWallPaper')
        ],
        typing.Annotated[
            types.MessageActionSetMessagesTTL,
            pydantic.Tag('MessageActionSetMessagesTTL')
        ],
        typing.Annotated[
            types.MessageActionSuggestProfilePhoto,
            pydantic.Tag('MessageActionSuggestProfilePhoto')
        ],
        typing.Annotated[
            types.MessageActionTopicCreate,
            pydantic.Tag('MessageActionTopicCreate')
        ],
        typing.Annotated[
            types.MessageActionTopicEdit,
            pydantic.Tag('MessageActionTopicEdit')
        ],
        typing.Annotated[
            types.MessageActionWebViewDataSent,
            pydantic.Tag('MessageActionWebViewDataSent')
        ],
        typing.Annotated[
            types.MessageActionWebViewDataSentMe,
            pydantic.Tag('MessageActionWebViewDataSentMe')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageActionGiftCode(BaseModel):
    """
    types.MessageActionGiftCode
    ID: 0x678c2e09
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageActionGiftCode', 'MessageActionGiftCode'] = pydantic.Field(
        'types.MessageActionGiftCode',
        alias='_'
    )

    months: int
    slug: str
    via_giveaway: typing.Optional[bool] = None
    unclaimed: typing.Optional[bool] = None
    boost_peer: typing.Optional["base.Peer"] = None
    currency: typing.Optional[str] = None
    amount: typing.Optional[int] = None
    crypto_currency: typing.Optional[str] = None
    crypto_amount: typing.Optional[int] = None



from .privacy_rules import PrivacyRules
from .authorizations import Authorizations
from .password import Password
from .password_settings import PasswordSettings
from .password_input_settings import PasswordInputSettings
from .tmp_password import TmpPassword
from .web_authorizations import WebAuthorizations
from .authorization_form import AuthorizationForm
from .sent_email_code import SentEmailCode
from .takeout import Takeout
from .wall_papers_not_modified import WallPapersNotModified
from .wall_papers import WallPapers
from .auto_download_settings import AutoDownloadSettings
from .themes_not_modified import ThemesNotModified
from .themes import Themes
from .content_settings import ContentSettings
from .reset_password_failed_wait import ResetPasswordFailedWait
from .reset_password_requested_wait import ResetPasswordRequestedWait
from .reset_password_ok import ResetPasswordOk
from .saved_ringtones_not_modified import SavedRingtonesNotModified
from .saved_ringtones import SavedRingtones
from .saved_ringtone import SavedRingtone
from .saved_ringtone_converted import SavedRingtoneConverted
from .emoji_statuses_not_modified import EmojiStatusesNotModified
from .emoji_statuses import EmojiStatuses
from .email_verified import EmailVerified
from .email_verified_login import EmailVerifiedLogin
from .auto_save_settings import AutoSaveSettings
from .connected_bots import ConnectedBots
from .business_chat_links import BusinessChatLinks
from .resolved_business_chat_links import ResolvedBusinessChatLinks



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateColor(BaseModel):
    """
    functions.account.UpdateColor
    ID: 0x7cefa15d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UpdateColor', 'UpdateColor'] = pydantic.Field(
        'functions.account.UpdateColor',
        alias='_'
    )

    for_profile: typing.Optional[bool] = None
    color: typing.Optional[int] = None
    background_emoji_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.PaymentReceipt - Layer 181
PaymentReceipt = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.payments.PaymentReceipt,
            pydantic.Tag('payments.PaymentReceipt'),
            pydantic.Tag('PaymentReceipt')
        ],
        typing.Annotated[
            types.payments.PaymentReceiptStars,
            pydantic.Tag('payments.PaymentReceiptStars'),
            pydantic.Tag('PaymentReceiptStars')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AvailableEffect(BaseModel):
    """
    types.AvailableEffect
    ID: 0x93c3e27e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AvailableEffect', 'AvailableEffect'] = pydantic.Field(
        'types.AvailableEffect',
        alias='_'
    )

    id: int
    emoticon: str
    effect_sticker_id: int
    premium_required: typing.Optional[bool] = None
    static_icon_id: typing.Optional[int] = None
    effect_animation_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.FeaturedStickers - Layer 181
FeaturedStickers = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.FeaturedStickers,
            pydantic.Tag('messages.FeaturedStickers'),
            pydantic.Tag('FeaturedStickers')
        ],
        typing.Annotated[
            types.messages.FeaturedStickersNotModified,
            pydantic.Tag('messages.FeaturedStickersNotModified'),
            pydantic.Tag('FeaturedStickersNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestPeerTypeChat(BaseModel):
    """
    types.RequestPeerTypeChat
    ID: 0xc9f06e1b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.RequestPeerTypeChat', 'RequestPeerTypeChat'] = pydantic.Field(
        'types.RequestPeerTypeChat',
        alias='_'
    )

    creator: typing.Optional[bool] = None
    bot_participant: typing.Optional[bool] = None
    has_username: typing.Optional[bool] = None
    forum: typing.Optional[bool] = None
    user_admin_rights: typing.Optional["base.ChatAdminRights"] = None
    bot_admin_rights: typing.Optional["base.ChatAdminRights"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ToggleGroupCallRecord(BaseModel):
    """
    functions.phone.ToggleGroupCallRecord
    ID: 0xf128c708
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.ToggleGroupCallRecord', 'ToggleGroupCallRecord'] = pydantic.Field(
        'functions.phone.ToggleGroupCallRecord',
        alias='_'
    )

    call: "base.InputGroupCall"
    start: typing.Optional[bool] = None
    video: typing.Optional[bool] = None
    title: typing.Optional[str] = None
    video_portrait: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# channels.SponsoredMessageReportResult - Layer 181
SponsoredMessageReportResult = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.channels.SponsoredMessageReportResultAdsHidden,
            pydantic.Tag('channels.SponsoredMessageReportResultAdsHidden'),
            pydantic.Tag('SponsoredMessageReportResultAdsHidden')
        ],
        typing.Annotated[
            types.channels.SponsoredMessageReportResultChooseOption,
            pydantic.Tag('channels.SponsoredMessageReportResultChooseOption'),
            pydantic.Tag('SponsoredMessageReportResultChooseOption')
        ],
        typing.Annotated[
            types.channels.SponsoredMessageReportResultReported,
            pydantic.Tag('channels.SponsoredMessageReportResultReported'),
            pydantic.Tag('SponsoredMessageReportResultReported')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputNotifyPeer - Layer 181
InputNotifyPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputNotifyBroadcasts,
            pydantic.Tag('InputNotifyBroadcasts')
        ],
        typing.Annotated[
            types.InputNotifyChats,
            pydantic.Tag('InputNotifyChats')
        ],
        typing.Annotated[
            types.InputNotifyForumTopic,
            pydantic.Tag('InputNotifyForumTopic')
        ],
        typing.Annotated[
            types.InputNotifyPeer,
            pydantic.Tag('InputNotifyPeer')
        ],
        typing.Annotated[
            types.InputNotifyUsers,
            pydantic.Tag('InputNotifyUsers')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetStarsTransactions(BaseModel):
    """
    functions.payments.GetStarsTransactions
    ID: 0x673ac2f9
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.payments.GetStarsTransactions', 'GetStarsTransactions'] = pydantic.Field(
        'functions.payments.GetStarsTransactions',
        alias='_'
    )

    peer: "base.InputPeer"
    offset: str
    inbound: typing.Optional[bool] = None
    outbound: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChangeAuthorizationSettings(BaseModel):
    """
    functions.account.ChangeAuthorizationSettings
    ID: 0x40f48462
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.ChangeAuthorizationSettings', 'ChangeAuthorizationSettings'] = pydantic.Field(
        'functions.account.ChangeAuthorizationSettings',
        alias='_'
    )

    hash: int
    confirmed: typing.Optional[bool] = None
    encrypted_requests_disabled: typing.Optional[bool] = None
    call_requests_disabled: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestedPeerChannel(BaseModel):
    """
    types.RequestedPeerChannel
    ID: 0x8ba403e4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.RequestedPeerChannel', 'RequestedPeerChannel'] = pydantic.Field(
        'types.RequestedPeerChannel',
        alias='_'
    )

    channel_id: int
    title: typing.Optional[str] = None
    username: typing.Optional[str] = None
    photo: typing.Optional["base.Photo"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UploadMedia(BaseModel):
    """
    functions.messages.UploadMedia
    ID: 0x14967978
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.UploadMedia', 'UploadMedia'] = pydantic.Field(
        'functions.messages.UploadMedia',
        alias='_'
    )

    peer: "base.InputPeer"
    media: "base.InputMedia"
    business_connection_id: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReplyKeyboardMarkup(BaseModel):
    """
    types.ReplyKeyboardMarkup
    ID: 0x85dd99d1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ReplyKeyboardMarkup', 'ReplyKeyboardMarkup'] = pydantic.Field(
        'types.ReplyKeyboardMarkup',
        alias='_'
    )

    rows: list["base.KeyboardButtonRow"]
    resize: typing.Optional[bool] = None
    single_use: typing.Optional[bool] = None
    selective: typing.Optional[bool] = None
    persistent: typing.Optional[bool] = None
    placeholder: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# upload.File - Layer 181
File = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.upload.File,
            pydantic.Tag('upload.File'),
            pydantic.Tag('File')
        ],
        typing.Annotated[
            types.upload.FileCdnRedirect,
            pydantic.Tag('upload.FileCdnRedirect'),
            pydantic.Tag('FileCdnRedirect')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.QuickReplies - Layer 181
QuickReplies = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.QuickReplies,
            pydantic.Tag('messages.QuickReplies'),
            pydantic.Tag('QuickReplies')
        ],
        typing.Annotated[
            types.messages.QuickRepliesNotModified,
            pydantic.Tag('messages.QuickRepliesNotModified'),
            pydantic.Tag('QuickRepliesNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdatePinnedSavedDialogs(BaseModel):
    """
    types.UpdatePinnedSavedDialogs
    ID: 0x686c85a6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdatePinnedSavedDialogs', 'UpdatePinnedSavedDialogs'] = pydantic.Field(
        'types.UpdatePinnedSavedDialogs',
        alias='_'
    )

    order: typing.Optional[list["base.DialogPeer"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateNewEncryptedMessage(BaseModel):
    """
    types.UpdateNewEncryptedMessage
    ID: 0x12bcbd9a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateNewEncryptedMessage', 'UpdateNewEncryptedMessage'] = pydantic.Field(
        'types.UpdateNewEncryptedMessage',
        alias='_'
    )

    message: "base.EncryptedMessage"
    qts: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Unblock(BaseModel):
    """
    functions.contacts.Unblock
    ID: 0xb550d328
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.contacts.Unblock', 'Unblock'] = pydantic.Field(
        'functions.contacts.Unblock',
        alias='_'
    )

    id: "base.InputPeer"
    my_stories_from: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class LeaveChatlist(BaseModel):
    """
    functions.chatlists.LeaveChatlist
    ID: 0x74fae13a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.chatlists.LeaveChatlist', 'LeaveChatlist'] = pydantic.Field(
        'functions.chatlists.LeaveChatlist',
        alias='_'
    )

    chatlist: "base.InputChatlist"
    peers: list["base.InputPeer"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelParticipantAdmin(BaseModel):
    """
    types.ChannelParticipantAdmin
    ID: 0x34c3bb53
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelParticipantAdmin', 'ChannelParticipantAdmin'] = pydantic.Field(
        'types.ChannelParticipantAdmin',
        alias='_'
    )

    user_id: int
    promoted_by: int
    date: Datetime
    admin_rights: "base.ChatAdminRights"
    can_edit: typing.Optional[bool] = None
    is_self: typing.Optional[bool] = pydantic.Field(
        None,
        serialization_alias='self',
        validation_alias=pydantic.AliasChoices('self', 'is_self')
    )
    inviter_id: typing.Optional[int] = None
    rank: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# NotificationSound - Layer 181
NotificationSound = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.NotificationSoundDefault,
            pydantic.Tag('NotificationSoundDefault')
        ],
        typing.Annotated[
            types.NotificationSoundLocal,
            pydantic.Tag('NotificationSoundLocal')
        ],
        typing.Annotated[
            types.NotificationSoundNone,
            pydantic.Tag('NotificationSoundNone')
        ],
        typing.Annotated[
            types.NotificationSoundRingtone,
            pydantic.Tag('NotificationSoundRingtone')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class LangPackStringPluralized(BaseModel):
    """
    types.LangPackStringPluralized
    ID: 0x6c47ac9f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.LangPackStringPluralized', 'LangPackStringPluralized'] = pydantic.Field(
        'types.LangPackStringPluralized',
        alias='_'
    )

    key: str
    other_value: str
    zero_value: typing.Optional[str] = None
    one_value: typing.Optional[str] = None
    two_value: typing.Optional[str] = None
    few_value: typing.Optional[str] = None
    many_value: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ImportedContacts(BaseModel):
    """
    types.contacts.ImportedContacts
    ID: 0x77d01c3b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.contacts.ImportedContacts', 'ImportedContacts'] = pydantic.Field(
        'types.contacts.ImportedContacts',
        alias='_'
    )

    imported: list["base.ImportedContact"]
    popular_invites: list["base.PopularContact"]
    retry_contacts: list[int]
    users: list["base.User"]
